==> kubernetes-model-apiextensions-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceDefinitionSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CustomResourceDefinitionSpecBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpecFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpec,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpecBuilder>{
  public CustomResourceDefinitionSpecBuilder() {
    this(false);
  }
  public CustomResourceDefinitionSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new CustomResourceDefinitionSpec(), validationEnabled);
  }
  public CustomResourceDefinitionSpecBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceDefinitionSpecBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CustomResourceDefinitionSpec(), validationEnabled);
  }
  public CustomResourceDefinitionSpecBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpec instance) {
    this(fluent, instance, false);
  }
  public CustomResourceDefinitionSpecBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConversion(instance.getConversion()); 
    fluent.withGroup(instance.getGroup()); 
    fluent.withNames(instance.getNames()); 
    fluent.withPreserveUnknownFields(instance.getPreserveUnknownFields()); 
    fluent.withScope(instance.getScope()); 
    fluent.withVersions(instance.getVersions()); 
    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceDefinitionSpecBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpec instance) {
    this(instance,false);
  }
  public CustomResourceDefinitionSpecBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConversion(instance.getConversion()); 
    this.withGroup(instance.getGroup()); 
    this.withNames(instance.getNames()); 
    this.withPreserveUnknownFields(instance.getPreserveUnknownFields()); 
    this.withScope(instance.getScope()); 
    this.withVersions(instance.getVersions()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpec build() {
    CustomResourceDefinitionSpec buildable = new CustomResourceDefinitionSpec(fluent.getConversion(),fluent.getGroup(),fluent.getNames(),fluent.getPreserveUnknownFields(),fluent.getScope(),fluent.getVersions());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceDefinitionSpecBuilder that = (CustomResourceDefinitionSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-apiextensions-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceDefinitionSpecBuilder.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CustomResourceDefinitionSpecBuilder extends io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpecFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpec,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpecBuilder>{
  public CustomResourceDefinitionSpecBuilder() {
    this(false);
  }
  public CustomResourceDefinitionSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new CustomResourceDefinitionSpec(), validationEnabled);
  }
  public CustomResourceDefinitionSpecBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public CustomResourceDefinitionSpecBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CustomResourceDefinitionSpec(), validationEnabled);
  }
  public CustomResourceDefinitionSpecBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpec instance) {
    this(fluent, instance, false);
  }
  public CustomResourceDefinitionSpecBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpecFluent<?> fluent,io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConversion(instance.getConversion()); 
    fluent.withGroup(instance.getGroup()); 
    fluent.withNames(instance.getNames()); 
    fluent.withPreserveUnknownFields(instance.getPreserveUnknownFields()); 
    fluent.withScope(instance.getScope()); 
    fluent.withVersions(instance.getVersions()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CustomResourceDefinitionSpecBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpec instance) {
    this(instance,false);
  }
  public CustomResourceDefinitionSpecBuilder(io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConversion(instance.getConversion()); 
    this.withGroup(instance.getGroup()); 
    this.withNames(instance.getNames()); 
    this.withPreserveUnknownFields(instance.getPreserveUnknownFields()); 
    this.withScope(instance.getScope()); 
    this.withVersions(instance.getVersions()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.apiextensions.v1.CustomResourceDefinitionSpec build() {
    CustomResourceDefinitionSpec buildable = new CustomResourceDefinitionSpec(fluent.getConversion(),fluent.getGroup(),fluent.getNames(),fluent.getPreserveUnknownFields(),fluent.getScope(),fluent.getVersions());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceDefinitionSpecBuilder that = (CustomResourceDefinitionSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
